@@ -13,10 +13,18 @@ def ip_addresses_parameter(_context, _parameter, values):
     :raises click.BadParameter: when any IP address value is invalid
 
     """
+    valid_ips = []
     for value in values:
         try:
-            validate_ip(value)
+            if "," in value:
+                split_value = value.split(",")
+                for item in split_value:
+                    validate_ip(item, strict=False)
+                    valid_ips.append(item)
+            else:
+                validate_ip(value)
+                valid_ips.append(value)
         except ValueError:
             raise click.BadParameter(value)
 
-    return values
+    return valid_ips
